@@ -1,7 +1,7 @@
 `print.micro` <-
 function(x, ...){
   cat(paste("\n Object created with method", x$method))
-  cat("\n -------------------------")
+  cat("\n -------------------------\n")
   cat("Try names(your object from class micro) for more details")
   cat("\n")
 }
